pub struct TempoBlockExecutor<'a, DB: Database, I> {
pub(crate) inner: EthBlockExecutor<'a, TempoEvm<DB, I>, &'a TempoChainSpec, TempoReceiptBuilder>,
section: BlockSection,
seen_subblocks: Vec<(PartialValidatorKey, Vec<TempoTxEnvelope>)>,
validator_set: Option<Vec<B256>>,
shared_gas_limit: u64,
subblock_fee_recipients: HashMap<PartialValidatorKey, Address>,
non_shared_gas_left: u64,
non_payment_gas_left: u64,
incentive_gas_used: u64,
}Expand description
Block executor for Tempo.
Wraps an inner [EthBlockExecutor] and layers Tempo-specific block execution
logic on top: section-based transaction ordering (BlockSection), subblock
validation, shared/non-shared gas accounting, and gas incentive tracking.
Fields
inner: EthBlockExecutor<'a, TempoEvm<DB, I>, &'a TempoChainSpec, TempoReceiptBuilder>section: BlockSectionseen_subblocks: Vec<(PartialValidatorKey, Vec<TempoTxEnvelope>)>validator_set: Option<Vec<B256>>subblock_fee_recipients: HashMap<PartialValidatorKey, Address>non_payment_gas_left: u64incentive_gas_used: u64Implementations
Sourceimpl<'a, DB, I> TempoBlockExecutor<'a, DB, I>where
DB: StateDB,
I: Inspector<TempoContext<DB>>,
impl<'a, DB, I> TempoBlockExecutor<'a, DB, I>where
DB: StateDB,
I: Inspector<TempoContext<DB>>,
pub(crate) fn new( evm: TempoEvm<DB, I>, ctx: TempoBlockExecutionCtx<'a>, chain_spec: &'a TempoChainSpec, ) -> Self
Sourcefn deploy_precompile_at_boundary(
&mut self,
address: Address,
) -> Result<(), BlockExecutionError>
fn deploy_precompile_at_boundary( &mut self, address: Address, ) -> Result<(), BlockExecutionError>
Deploys 0xEF marker bytecode to a precompile address if it doesn’t already have code.
This also dispatches the state change to the system caller’s state hook so that the sparse trie task is aware of the change.
Sourcepub(crate) fn validate_system_tx(
&self,
tx: &TempoTxEnvelope,
) -> Result<BlockSection, BlockValidationError>
pub(crate) fn validate_system_tx( &self, tx: &TempoTxEnvelope, ) -> Result<BlockSection, BlockValidationError>
Validates a system transaction.
Sourcepub(crate) fn validate_tx_pre_execution(
&self,
tx: &TempoTxEnvelope,
) -> Result<Option<BlockSection>, BlockValidationError>
pub(crate) fn validate_tx_pre_execution( &self, tx: &TempoTxEnvelope, ) -> Result<Option<BlockSection>, BlockValidationError>
Pre-validate a transaction before execution.
This is only done for system transaction as they are effectively bypassing the regular block gas limit checks and we need to make sure that they only perform explicitly allowed actions.
pub(crate) fn validate_tx( &self, tx: &TempoTxEnvelope, gas_used: u64, ) -> Result<BlockSection, BlockValidationError>